==> huaweicloudsdkcsms-3.1.137-py2.py3-none-any.whl: huaweicloudsdkcsms/v1/model/list_users_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListUsersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'users': 'list[UsersDetailsResult]'
    }

    attribute_map = {
        'total': 'total',
        'users': 'users'
    }

    def __init__(self, total=None, users=None):
        """ListUsersResponse

        The model defined in huaweicloud sdk

        :param total: 用户总数。
        :type total: int
        :param users: 用户列表。
        :type users: list[:class:`huaweicloudsdkcsms.v1.UsersDetailsResult`]
        """
        
        super(ListUsersResponse, self).__init__()

        self._total = None
        self._users = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if users is not None:
            self.users = users

    @property
    def total(self):
        """Gets the total of this ListUsersResponse.

        用户总数。

        :return: The total of this ListUsersResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListUsersResponse.

        用户总数。

        :param total: The total of this ListUsersResponse.
        :type total: int
        """
        self._total = total

    @property
    def users(self):
        """Gets the users of this ListUsersResponse.

        用户列表。

        :return: The users of this ListUsersResponse.
        :rtype: list[:class:`huaweicloudsdkcsms.v1.UsersDetailsResult`]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this ListUsersResponse.

        用户列表。

        :param users: The users of this ListUsersResponse.
        :type users: list[:class:`huaweicloudsdkcsms.v1.UsersDetailsResult`]
        """
        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListUsersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcsms-3.1.146-py2.py3-none-any.whl: huaweicloudsdkcsms/v1/model/list_users_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListUsersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'users': 'list[UsersDetailsResult]'
    }

    attribute_map = {
        'total': 'total',
        'users': 'users'
    }

    def __init__(self, total=None, users=None):
        r"""ListUsersResponse

        The model defined in huaweicloud sdk

        :param total: 用户总数。
        :type total: int
        :param users: 用户列表。
        :type users: list[:class:`huaweicloudsdkcsms.v1.UsersDetailsResult`]
        """
        
        super(ListUsersResponse, self).__init__()

        self._total = None
        self._users = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if users is not None:
            self.users = users

    @property
    def total(self):
        r"""Gets the total of this ListUsersResponse.

        用户总数。

        :return: The total of this ListUsersResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListUsersResponse.

        用户总数。

        :param total: The total of this ListUsersResponse.
        :type total: int
        """
        self._total = total

    @property
    def users(self):
        r"""Gets the users of this ListUsersResponse.

        用户列表。

        :return: The users of this ListUsersResponse.
        :rtype: list[:class:`huaweicloudsdkcsms.v1.UsersDetailsResult`]
        """
        return self._users

    @users.setter
    def users(self, users):
        r"""Sets the users of this ListUsersResponse.

        用户列表。

        :param users: The users of this ListUsersResponse.
        :type users: list[:class:`huaweicloudsdkcsms.v1.UsersDetailsResult`]
        """
        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListUsersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
